==> haskell-cipher-aes128-0.7.0.6-9-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-cipher-aes128.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cipher-aes128
version:              0.7.0.6
visibility:           public
id:                   cipher-aes128-0.7.0.6-DBAAA18Kt7cIu1qxwlxwQn
key:                  cipher-aes128-0.7.0.6-DBAAA18Kt7cIu1qxwlxwQn
license:              BSD-3-Clause
copyright:            Thomas M. DuBuisson
maintainer:           thomas.dubuisson@gmail.com
author:               Thomas M. DuBuisson, Vincent Hanquez (See AUTHORS file)
homepage:             https://github.com/TomMD/cipher-aes128
synopsis:             AES and common modes using AES-NI when available.
description:
    Cipher-aes128 is an implementation of AES and common modes of operation.  It borrows Hanquez'\''s C AES code (see '\''cipher-aes'\'') but
    is unique due to including compile-time detection of
    NI compiler support, a slightly more functional interface
    for GCM operations, exposure of '\''Ptr'\'' based operations via the .Internal module, and build-in crypto-api support.
    Cipher-aes128 was originally developed as "'\''cipher-aes'\'' plus trampolines", which has since been adopted into cipher-aes.

category:             Cryptography
abi:                  69fa725c24138db4f1107f030d451de6
exposed:              True
exposed-modules:      Crypto.Cipher.AES128 Crypto.Cipher.AES128.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/cipher-aes128-0.7.0.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cipher-aes128-0.7.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cipher-aes128
hs-libraries:         HScipher-aes128-0.7.0.6-DBAAA18Kt7cIu1qxwlxwQn
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
    crypto-api-0.13.3-95IFBy4WvL6L3p6UFm5MLc
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg

haddock-interfaces:
    /usr/share/doc/haskell-cipher-aes128/html/cipher-aes128.haddock

haddock-html:         /usr/share/doc/haskell-cipher-aes128/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cipher-aes128-0.7.0.6-11-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-cipher-aes128.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cipher-aes128
version:              0.7.0.6
visibility:           public
id:                   cipher-aes128-0.7.0.6-JhlrYiWt4AmHByy7vknJZT
key:                  cipher-aes128-0.7.0.6-JhlrYiWt4AmHByy7vknJZT
license:              BSD-3-Clause
copyright:            Thomas M. DuBuisson
maintainer:           thomas.dubuisson@gmail.com
author:               Thomas M. DuBuisson, Vincent Hanquez (See AUTHORS file)
homepage:             https://github.com/TomMD/cipher-aes128
synopsis:             AES and common modes using AES-NI when available.
description:
    Cipher-aes128 is an implementation of AES and common modes of operation.  It borrows Hanquez'\''s C AES code (see '\''cipher-aes'\'') but
    is unique due to including compile-time detection of
    NI compiler support, a slightly more functional interface
    for GCM operations, exposure of '\''Ptr'\'' based operations via the .Internal module, and build-in crypto-api support.
    Cipher-aes128 was originally developed as "'\''cipher-aes'\'' plus trampolines", which has since been adopted into cipher-aes.

category:             Cryptography
abi:                  b55c71581ab4a0fc690d1696f1beabaa
exposed:              True
exposed-modules:      Crypto.Cipher.AES128 Crypto.Cipher.AES128.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/cipher-aes128-0.7.0.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cipher-aes128-0.7.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cipher-aes128
hs-libraries:         HScipher-aes128-0.7.0.6-JhlrYiWt4AmHByy7vknJZT
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
    crypto-api-0.13.3-C1qJbx2RCzA2NPKTjJGXlO
    tagged-0.8.9-KXBukbFHRBNBMyyfjfj7aP

haddock-interfaces:
    /usr/share/doc/haskell-cipher-aes128/html/cipher-aes128.haddock

haddock-html:         /usr/share/doc/haskell-cipher-aes128/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
